@@ -63,14 +63,9 @@ warnings.filterwarnings(
 )
 
 
-from plangym.atari import AtariEnvironment  # noqa: E402
-from plangym.box_2d import Box2DEnv, LunarLander  # noqa: E402
-from plangym.classic_control import ClassicControl  # noqa: E402
+from plangym.control import Box2DEnv, ClassicControl, DMControlEnv, LunarLander  # noqa: E402
 from plangym.core import PlanEnvironment  # noqa: E402
-from plangym.dm_control import DMControlEnv  # noqa: E402
-from plangym.montezuma import Montezuma  # noqa: E402
-from plangym.parallel import ParallelEnvironment  # noqa: E402
-from plangym.ray import RayEnv  # noqa: E402
 from plangym.registry import make  # noqa: E402
-from plangym.retro import RetroEnvironment  # noqa: E402
+from plangym.vectorization import ParallelEnvironment, RayEnv  # noqa: E402
 from plangym.version import __version__  # noqa: E402
+from plangym.videogames import AtariEnv, MarioEnv, Montezuma, RetroEnv  # noqa: E402
